# coding: utf-8

from json import dumps
from json import loads

import requests


JIRA_AUTH_URL = 'https://jira.bars-open.ru/rest/auth/1/session'
JIRA_GET_ISSUE = 'https://jira.bars-open.ru/rest/api/2/issue/'


class Jira(object):
    """
    Класс для работы с jira.bars-open.ru
    :type username: str
    :type password: str
    """
    def __init__(self, username, password):
        self.username = username
        self.password = password
        self.connection_error_code = 0
        self._session = self.__create_session()

    def __create_session(self):
        """
        Создает авторизированную сессию.
        """
        session = requests.Session()
        session.headers = {'Content-Type': 'application/json'}
        session.verify = True
        session.auth = (self.username, self.password)
        pload = {
            'username': self.username,
            'password': self.password
        }
        try:
            session.post(JIRA_AUTH_URL, data=dumps(pload), timeout=10)
        except:
            self.connection_error_code = 1
        return session

    def get_issue_status(self, issue_name):
        """
        Проверка статуса задачи. Если задача не была найдена,
        то считаем ее закрытой.
        """
        issue_name = issue_name.upper()
        resp = self._session.get(''.join([JIRA_GET_ISSUE, issue_name]))
        try:
            issue_status = loads(resp.content)['fields']['status']['name']
        except KeyError:
            issue_status = u'Закрыт'
        return issue_status
